@@ -77,7 +77,7 @@ print(setu.__doc__)查看说明
 
     fullUrl = url + paramUrl
     while '&&' in fullUrl:
-        fullUrl = fullUrl.replace('&&','') 
+        fullUrl = fullUrl.replace('&&','&') 
     while fullUrl[-1] == "&":
         fullUrl = fullUrl[:-1]
 
